@@ -341,7 +341,7 @@ class SliceTest(g.unittest.TestCase):
             return
 
         from trimesh.transformations import random_rotation_matrix
-        for i in range(100):
+        for _i in range(100):
             box1 = g.trimesh.primitives.Box(
                 extents=[10, 20, 30],
                 transform=random_rotation_matrix())
