@@ -11,28 +11,39 @@ Convex is defined as:
 
 import numpy as np
 
-from .constants import tol, log
+from .constants import tol
 
 from . import util
 from . import triangles
 
 
 try:
-    from scipy import spatial
-except ImportError:
-    log.warning('Scipy import failed!')
+    from scipy.spatial import ConvexHull
+except ImportError as E:
+    from .exceptions import ExceptionWrapper
+    ConvexHull = ExceptionWrapper(E)
+
+try:
+    from scipy.spatial import QhullError
+except BaseException:
+    QhullError = BaseException
 
 
-def convex_hull(obj, qhull_options='QbB Pp QJn'):
+def convex_hull(obj, qhull_options='QbB Pp Qt', repair=True):
     """
     Get a new Trimesh object representing the convex hull of the
-    current mesh, with proper normals and watertight.
-    Requires scipy >.12.
+    current mesh attempting to return a watertight mesh with correct
+    normals.
+
+    Details on qhull options:
+      http://www.qhull.org/html/qh-quick.htm#options
 
     Arguments
     --------
     obj : Trimesh, or (n,3) float
       Mesh or cartesian points
+    qhull_options : str
+      Options to pass to qhull.
 
     Returns
     --------
@@ -49,8 +60,14 @@ def convex_hull(obj, qhull_options='QbB Pp QJn'):
         if not util.is_shape(points, (-1, 3)):
             raise ValueError('Object must be Trimesh or (n,3) points!')
 
-    hull = spatial.ConvexHull(points,
-                              qhull_options=qhull_options)
+    try:
+        hull = ConvexHull(points, qhull_options=qhull_options)
+    except QhullError:
+        util.log.debug(
+            'Failed to compute convex hull: retrying with `QJ`',
+            exc_info=True)
+        # try with "joggle" enabled
+        hull = ConvexHull(points, qhull_options='QJ')
 
     # hull object doesn't remove unreferenced vertices
     # create a mask to re- index faces for only referenced vertices
@@ -59,10 +76,16 @@ def convex_hull(obj, qhull_options='QbB Pp QJn'):
     mask[vid] = np.arange(len(vid))
     # remove unreferenced vertices here
     faces = mask[hull.simplices].copy()
-
     # rescale vertices back to original size
     vertices = hull.points[vid].copy()
 
+    if not repair:
+        # create the Trimesh object for the convex hull
+        return Trimesh(vertices=vertices,
+                       faces=faces,
+                       process=True,
+                       validate=False)
+
     # qhull returns faces with random winding
     # calculate the returned normal of each face
     crosses = triangles.cross(vertices[faces])
@@ -89,8 +112,7 @@ def convex_hull(obj, qhull_options='QbB Pp QJn'):
     # a vector from the centroid to a point on each face
     test_vector = triangles_center - centroid
     # check the projection against face normals
-    backwards = util.diagonal_dot(normals,
-                                  test_vector) < 0.0
+    backwards = util.diagonal_dot(normals, test_vector) < 0.0
 
     # flip the winding outward facing
     faces[backwards] = np.fliplr(faces[backwards])
@@ -171,17 +193,29 @@ def is_convex(mesh):
     convex : bool
       Was passed mesh convex or not
     """
-    # don't consider zero- area faces
-    nonzero = mesh.area_faces > tol.merge
+    # non-watertight meshes are not convex
+    if not mesh.is_watertight:
+        return False
 
+    # don't consider zero- area faces
+    nonzero = mesh.area_faces > tol.zero
     # adjacencies with two nonzero faces
     adj_ok = nonzero[mesh.face_adjacency].all(axis=1)
 
+    # if none of our face pairs are both nonzero exit
+    # TODO : is this the correct check?
+    # or should we just compare the projections
+    # to the mesh scale
+    if not adj_ok.any():
+        return False
+
     # make threshold of convexity scale- relative
     threshold = tol.planar * mesh.scale
+
     # if projections of vertex onto plane of adjacent
     # face is negative, it means the face pair is locally
     # convex, and if that is true for all faces the mesh is convex
+
     convex = bool(mesh.face_adjacency_projections[adj_ok].max() < threshold)
 
     return convex
@@ -207,8 +241,7 @@ def hull_points(obj, qhull_options='QbB Pp'):
     initial = np.asanyarray(obj, dtype=np.float64)
     if len(initial.shape) != 2:
         raise ValueError('points must be (n, dimension)!')
-
-    hull = spatial.ConvexHull(initial, qhull_options=qhull_options)
+    hull = ConvexHull(initial, qhull_options=qhull_options)
     points = hull.points[hull.vertices]
 
     return points
