@@ -71,7 +71,6 @@ class RectangleBin:
           Position of insertion in the tree or None
           if the insertion was unsuccessful.
         """
-
         for child in self.child:
             # try inserting into child cells
             attempt = child.insert(size=size, rotate=rotate)
@@ -184,7 +183,7 @@ def rectangles_single(extents, size=None, shuffle=False, rotate=True):
     bounds : (m, 2, dim) float
       Axis aligned resulting bounds in space
     transforms : (m, dim + 1, dim + 1) float
-      Homogenous transformation including rotation.
+      Homogeneous transformation including rotation.
     consume : (n,) bool
       Which of the original rectangles were packed,
       i.e. `consume.sum() == m`
@@ -323,7 +322,7 @@ def paths(paths, **kwargs):
     packed : trimesh.path.Path2D
       All paths packed into a single path object.
     transforms : (m, 3, 3) float
-      Homogenous transforms to move paths from their
+      Homogeneous transforms to move paths from their
       original position to the new one.
     consume : (n,) bool
       Which of the original paths were inserted,
@@ -521,18 +520,19 @@ def images(images, power_resize=False):
 
     # offsets should be integer multiple of pizels
     offset = bounds[:, 0].round().astype(int)
-
     extents = bounds.reshape((-1, 2)).ptp(axis=0)
     size = extents.round().astype(int)
     if power_resize:
         # round up all dimensions to powers of 2
         size = (2 ** np.ceil(np.log2(size))).astype(np.int64)
 
-    # create the image
-    result = Image.new('RGB', tuple(size))
+    # create the image in the mode of the first image
+    result = Image.new(images[0].mode, tuple(size))
     # paste each image into the result
     for img, off in zip(images, offset):
-        result.paste(img, tuple(off))
+        # box is upper left corner
+        corner = (off[0], size[1] - img.size[1] - off[1])
+        result.paste(img, box=corner)
 
     return result, offset
 
@@ -553,7 +553,7 @@ def meshes(meshes, **kwargs):
     placed : (m,) trimesh.Trimesh
       Meshes moved into the rectangular volume.
     transforms : (m, 4, 4) float
-      Homogenous transform moving mesh from original
+      Homogeneous transform moving mesh from original
       position to being packed in a rectangular volume.
     consume : (n,) bool
       Which of the original meshes were inserted,
@@ -617,7 +617,7 @@ def visualize(extents, bounds):
 def roll_transform(bounds, extents):
     """
     Packing returns rotations with integer "roll" which
-    needs to be converted into a homogenous rotation matrix.
+    needs to be converted into a homogeneous rotation matrix.
 
     Currently supports `dimension=2` and `dimension=3`.
 
@@ -632,7 +632,7 @@ def roll_transform(bounds, extents):
     Returns
     ----------
     transforms : (n, dimension + 1, dimension + 1) float
-      Homogenous transformation to move cuboid at the origin
+      Homogeneous transformation to move cuboid at the origin
       into the position determined by `bounds`.
     """
     if len(bounds) != len(extents):
